package com.bcxin.api.interfaces.tenants.responses;

import com.bcxin.Infrastructures.enums.CompanyNature;
import com.bcxin.api.interfaces.commons.responses.CompanyResponse;
import com.bcxin.api.interfaces.tenants.requests.organizations.CompanyRegistrationRequest;
import com.bcxin.api.interfaces.tenants.requests.organizations.LocationRequest;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;
import java.util.Arrays;

/**
 * @author huangdunye
 * 2023/5/8 17:59
 */
@Getter
@Setter
public class TenantCompanyResponse implements Serializable {

    @ApiModelProperty(value = "id")
    private String id;
    /**
     * 公司名称
     */
    @ApiModelProperty(value = "公司名称")
    private String companyName;
    /**
     * 公司类型
     */
    @ApiModelProperty(value = "公司类型")
    private String companyType;
    /**
     * 公司电话
     */
    @ApiModelProperty(value = "公司电话")
    private String phone;
    /**
     * 法人姓名
     */
    @ApiModelProperty(value = "法人姓名")
    private String legalName;
    /**
     * 法人身份证
     */
    @ApiModelProperty(value = "法人身份证")
    private String legalCardNumber;
    /**
     * 法人电话
     */
    @ApiModelProperty(value = "法人电话")
    private String legalPhone;
    /**
     * 注册资本
     */
    @ApiModelProperty(value = "注册资本")
    private String registeredCapital;
    /**
     * 服务范围
     */
    @ApiModelProperty(value = "服务范围")
    private String businessScope;
    /**
     * 保安负责人姓名
     */
    @ApiModelProperty(value = "保安负责人姓名")
    private String chargeName;
    /**
     * 保安负责人电话
     */
    @ApiModelProperty(value = "保安负责人电话")
    private String chargePhone;
    /**
     * 保安负责人证件号
     */
    @ApiModelProperty(value = "保安负责人证件号")
    private String chargeCardNumber;
    /**
     * 监管地区
     */
    @ApiModelProperty(value = "监管地区")
    private String address;
    /**
     * 监管机构
     */
    @ApiModelProperty(value = "监管机构")
    private String officePoliceAddress;
    /**
     * 培训内容
     */
    @ApiModelProperty(value = "培训内容")
    private String trainingContent;
    /**
     * 统一社会信用代码
     */
    @ApiModelProperty(value = "统一社会信用代码")
    private String creditCode;
    /**
     * 保安人数
     */
    @ApiModelProperty(value = "保安人数")
    private String recordPersonNum;


    /**
     * description: 转企业返回对象信息
     * author: linchunpeng
     * date:  2023-05-10 14:22
     */
    public void setCompanyValue(CompanyResponse companyResponse) {
        if (StringUtils.isNotBlank(this.getCompanyName())) {
            companyResponse.setName(this.getCompanyName());
        }
//        if (StringUtils.isNotBlank(this.getCompanyType())) {
//            companyResponse.setNature(Integer.parseInt(this.getCompanyType()));
//        }
        if (StringUtils.isNotBlank(this.getPhone())) {
            companyResponse.setTelephone(this.getPhone());
        }
        if (StringUtils.isNotBlank(this.getLegalName())) {
            companyResponse.setLegalPersonName(this.getLegalName());
        }
        if (StringUtils.isNotBlank(this.getLegalCardNumber())) {
            companyResponse.setLegalPersonCredentialNumber(this.getLegalCardNumber());
        }
        if (StringUtils.isNotBlank(this.getLegalPhone())) {
            companyResponse.setLegalPersonTelephone(this.getLegalPhone());
        }
        if (StringUtils.isNotBlank(this.getRegisteredCapital())) {
            companyResponse.setRegisteredCapital(this.getRegisteredCapital());
        }
        if (StringUtils.isNotBlank(this.getBusinessScope())) {
            companyResponse.setServiceScopeList(Arrays.asList(this.getBusinessScope().split(";")));
        }
        if (StringUtils.isNotBlank(this.getChargeName())) {
            companyResponse.setSecurityPersonName(this.getChargeName());
        }
        if (StringUtils.isNotBlank(this.getChargePhone())) {
            companyResponse.setSecurityPersonTelephone(this.getChargePhone());
        }
        if (StringUtils.isNotBlank(this.getChargeCardNumber())) {
            companyResponse.setSecurityPersonCredentialNumber(this.getChargeCardNumber());
        }
        if (StringUtils.isNotBlank(this.getAddress())) {
            if (companyResponse.getPlaceOfSupervise() == null) {
                companyResponse.setPlaceOfSupervise(new LocationRequest());
            }
            if (companyResponse.getPlaceOfSupervise().getProvince() == null) {
                companyResponse.getPlaceOfSupervise().setProvince(new LocationRequest.ItemValueRequest());
            }
            if (companyResponse.getPlaceOfSupervise().getCity() == null) {
                companyResponse.getPlaceOfSupervise().setCity(new LocationRequest.ItemValueRequest());
            }
            if (companyResponse.getPlaceOfSupervise().getDistrict() == null) {
                companyResponse.getPlaceOfSupervise().setDistrict(new LocationRequest.ItemValueRequest());
            }

            companyResponse.getPlaceOfSupervise().getProvince().setCode(this.getAddress().substring(0,2).concat("0000"));
            companyResponse.getPlaceOfSupervise().getCity().setCode(this.getAddress().substring(0,4).concat("00"));
            companyResponse.getPlaceOfSupervise().getDistrict().setCode(this.getAddress());
        }
        if (StringUtils.isNotBlank(this.getOfficePoliceAddress())) {
            companyResponse.setSuperviseDepartId(this.getOfficePoliceAddress());
        }
        if (StringUtils.isNotBlank(this.getTrainingContent())) {
            companyResponse.setTrainContent(this.getTrainingContent());
        }
        if (StringUtils.isNotBlank(this.getCreditCode())) {
            companyResponse.setUnifySocialCreditCode(this.getCreditCode());
        }
        if (StringUtils.isNotBlank(this.getRecordPersonNum())) {
            companyResponse.setNumberOfSecurityGuards((int) Double.parseDouble(this.getRecordPersonNum()));
        }
    }


    /**
     * description: 转注册对象信息
     * author: linchunpeng
     * date:  2023-05-10 14:22
     */
    public void setCompanyRegistrationRequestValue(CompanyRegistrationRequest registrationRequest) {
        if (StringUtils.isNotBlank(this.getCompanyName())) {
            registrationRequest.setName(this.getCompanyName());
        }
//        if (StringUtils.isNotBlank(this.getCompanyType())) {
//            registrationRequest.setNature(CompanyNature.values()[Integer.parseInt(this.getCompanyType())]);
//        }
        if (StringUtils.isNotBlank(this.getPhone())) {
            registrationRequest.setTelephone(this.getPhone());
        }
        if (StringUtils.isNotBlank(this.getLegalName())) {
            registrationRequest.setLegalPersonName(this.getLegalName());
        }
        if (StringUtils.isNotBlank(this.getLegalCardNumber())) {
            registrationRequest.setLegalPersonCredentialNumber(this.getLegalCardNumber());
        }
        if (StringUtils.isNotBlank(this.getLegalPhone())) {
            registrationRequest.setLegalPersonTelephone(this.getLegalPhone());
        }
        if (StringUtils.isNotBlank(this.getRegisteredCapital())) {
            registrationRequest.setRegisteredCapital(this.getRegisteredCapital());
        }
        if (StringUtils.isNotBlank(this.getBusinessScope())) {
            registrationRequest.setServiceScopeList(Arrays.asList(this.getBusinessScope().split(";")));
        }
        if (StringUtils.isNotBlank(this.getChargeName())) {
            registrationRequest.setSecurityPersonName(this.getChargeName());
        }
        if (StringUtils.isNotBlank(this.getChargePhone())) {
            registrationRequest.setSecurityPersonTelephone(this.getChargePhone());
        }
        if (StringUtils.isNotBlank(this.getChargeCardNumber())) {
            registrationRequest.setSecurityPersonCredentialNumber(this.getChargeCardNumber());
        }
        if (StringUtils.isNotBlank(this.getAddress())) {
            if (registrationRequest.getPlaceOfSupervise() == null) {
                registrationRequest.setPlaceOfSupervise(new LocationRequest());
            }
            if (registrationRequest.getPlaceOfSupervise().getProvince() == null) {
                registrationRequest.getPlaceOfSupervise().setProvince(new LocationRequest.ItemValueRequest());
            }
            if (registrationRequest.getPlaceOfSupervise().getCity() == null) {
                registrationRequest.getPlaceOfSupervise().setCity(new LocationRequest.ItemValueRequest());
            }
            if (registrationRequest.getPlaceOfSupervise().getDistrict() == null) {
                registrationRequest.getPlaceOfSupervise().setDistrict(new LocationRequest.ItemValueRequest());
            }

            registrationRequest.getPlaceOfSupervise().getProvince().setCode(this.getAddress().substring(0,2).concat("0000"));
            registrationRequest.getPlaceOfSupervise().getCity().setCode(this.getAddress().substring(0,4).concat("00"));
            registrationRequest.getPlaceOfSupervise().getDistrict().setCode(this.getAddress());
        }
        if (StringUtils.isNotBlank(this.getOfficePoliceAddress())) {
            registrationRequest.setSuperviseDepartId(this.getOfficePoliceAddress());
        }
        if (StringUtils.isNotBlank(this.getTrainingContent())) {
            registrationRequest.setTrainContent(this.getTrainingContent());
        }
        if (StringUtils.isNotBlank(this.getCreditCode())) {
            registrationRequest.setUnifySocialCreditCode(this.getCreditCode());
        }
        if (StringUtils.isNotBlank(this.getRecordPersonNum())) {
            registrationRequest.setNumberOfSecurityGuards(Integer.parseInt(this.getRecordPersonNum()));
        }
    }

}
